@@ -2,7 +2,7 @@ use std::env;
 
 fn main() {
     // Validate the kernel selection and select `std` if none are selected
-    const KERNEL_LIST: &[&str] = &["asp3"];
+    const KERNEL_LIST: &[&str] = &["asp3", "fmp3", "solid_asp3", "solid_fmp3"];
     let selected_kernels: Vec<_> = KERNEL_LIST
         .iter()
         .filter(|name| {
@@ -19,5 +19,9 @@ fn main() {
         println!("cargo:rustc-cfg=feature=\"none\"");
         println!("cargo:rustc-cfg=feature=\"dcre\"");
         println!("cargo:rustc-cfg=feature=\"rstr_task\"");
+        println!("cargo:rustc-cfg=feature=\"messagebuf\"");
+        println!("cargo:rustc-cfg=feature=\"ovrhdr\"");
+        println!("cargo:rustc-cfg=feature=\"subprio\"");
+        println!("cargo:rustc-cfg=feature=\"pi_mutex\"");
     }
 }
