@@ -7,7 +7,12 @@ use super::{bool_t, ER, ER_BOOL, INTNO, PRI};
 pub const TIPM_ENAALL: PRI = 0;
 
 /// 割込み管理機能
-#[cfg(feature = "asp3")]
+#[cfg(any(
+    feature = "asp3",
+    feature = "fmp3",
+    feature = "solid_asp3",
+    feature = "solid_fmp3"
+))]
 extern "C" {
     pub fn dis_int(intno: INTNO) -> ER;
     pub fn ena_int(intno: INTNO) -> ER;
@@ -18,8 +23,15 @@ extern "C" {
     pub fn get_ipm(p_intpri: *mut PRI) -> ER;
 }
 
+// TODO: `acre_isr`
+
 /// CPU例外管理機能
-#[cfg(feature = "asp3")]
+#[cfg(any(
+    feature = "asp3",
+    feature = "fmp3",
+    feature = "solid_asp3",
+    feature = "solid_fmp3"
+))]
 extern "C" {
     pub fn xsns_dpn(p_excinf: *mut u8) -> bool_t;
 }
